@@ -448,8 +448,10 @@ gsf_xml_probe_element (GsfXMLProbeState *state,
 		       int nb_defaulted,
 		       const xmlChar **attributes)
 {
-	state->success = (state->func) (name, prefix, URI, nb_namespaces, namespaces,
-					nb_attributes, nb_defaulted, attributes);
+	state->success =
+		state->func &&
+		state->func (name, prefix, URI, nb_namespaces, namespaces,
+			     nb_attributes, nb_defaulted, attributes);
 	state->func = NULL;
 }
 
@@ -738,7 +740,7 @@ gsf_xml_in_start_element (GsfXMLInInternal *state, xmlChar const *name, xmlChar
 	if (state->unknown_depth++ > 0)
 		return;
 
-	g_print ("Unexpected element '%s' in state : \n\t", name);
+	g_printerr ("Unexpected element '%s' in state : \n\t", name);
 	ptr = state->pub.node_stack = g_slist_reverse (state->pub.node_stack);
 	if (ptr != NULL)	/* skip toplevel catch all */
 		ptr = ptr->next;
@@ -746,11 +748,11 @@ gsf_xml_in_start_element (GsfXMLInInternal *state, xmlChar const *name, xmlChar
 		node = ptr->data;
 		if (node != NULL) {
 /* FIXME FIXME FIXME if we really want this do we also want namespaces ? */
-			g_print ("%s -> ", node_name (&node->pub));
+			g_printerr ("%s -> ", node_name (&node->pub));
 		}
 	}
 	if (state->pub.node != NULL) {
-		g_print ("%s\n", node_name (state->pub.node));
+		g_printerr ("%s\n", node_name (state->pub.node));
 	}
 	state->pub.node_stack = g_slist_reverse (state->pub.node_stack);
 }
@@ -1134,7 +1136,7 @@ gsf_xml_in_doc_set_unknown_handler (GsfXMLInDoc *doc,
  * @dtor : #GsfXMLInExtDtor
  * @attrs : array of xmlChar const *
  *
- * Take the first node from @doc as the current node and call it's start handler.
+ * Take the first node from @doc as the current node and call its start handler.
  **/
 void
 gsf_xml_in_push_state (GsfXMLIn *xin, GsfXMLInDoc const *doc,
